==> imp-doc-2.1.1.tar.gz: html/classIMP_1_1multifit_1_1FFTFitting.js <==
var classIMP_1_1multifit_1_1FFTFitting =
[
    [ "FFTFitting", "classIMP_1_1multifit_1_1FFTFitting.html#a62ebb622f0d78309397c0400981fb658", null ],
    [ "copy_density_data", "classIMP_1_1multifit_1_1FFTFitting.html#aaeb4a52a506bcee42b2cacb393fbaa43", null ],
    [ "crop_margin", "classIMP_1_1multifit_1_1FFTFitting.html#a37d65339d5125709922ec82eba2ce9ed", null ],
    [ "detect_top_fits", "classIMP_1_1multifit_1_1FFTFitting.html#ac4e0b3ee481b867448bdb5e5fed83115", null ],
    [ "do_global_fitting", "classIMP_1_1multifit_1_1FFTFitting.html#a136cac955ee735ec87b1238b82aa67ac", null ],
    [ "do_local_fitting", "classIMP_1_1multifit_1_1FFTFitting.html#ae47864b146f9cf99c92495967e611d01", null ],
    [ "fftw_translational_search", "classIMP_1_1multifit_1_1FFTFitting.html#a74dba3ac8f5c530c2a3dd6bdd1a1cff7", null ],
    [ "get_type_name", "classIMP_1_1multifit_1_1FFTFitting.html#acc987cb7e2795126e5294508dd617280", null ],
    [ "get_unwrapped_index", "classIMP_1_1multifit_1_1FFTFitting.html#acd7df257d05cf51d782a013210e4572d", null ],
    [ "get_version_info", "classIMP_1_1multifit_1_1FFTFitting.html#a35fd010b9b680ba85976e05d5da635dd", null ],
    [ "pad_resolution_map", "classIMP_1_1multifit_1_1FFTFitting.html#accd7f75da3e55504aca2b9abda45ee1e", null ],
    [ "prepare_kernels", "classIMP_1_1multifit_1_1FFTFitting.html#af94977d86c307960a89b1a15d4cbda63", null ],
    [ "prepare_lowres_map", "classIMP_1_1multifit_1_1FFTFitting.html#ab063459cb69df88446f638fded7d95da", null ],
    [ "prepare_poslist", "classIMP_1_1multifit_1_1FFTFitting.html#aced49e5f2dae277cdcc74732c76c4aca", null ],
    [ "prepare_poslist_flipped", "classIMP_1_1multifit_1_1FFTFitting.html#a91969e61ffab79ed9b4f9cd5d222ef37", null ],
    [ "prepare_probe", "classIMP_1_1multifit_1_1FFTFitting.html#ab18f1bb918cf5b1f45d22d800a80fad4", null ],
    [ "asmb_norm_", "classIMP_1_1multifit_1_1FFTFitting.html#a219ce1447901c5e07e307272a5d21345", null ],
    [ "best_fits_", "classIMP_1_1multifit_1_1FFTFitting.html#aabb824cdadbf5fee5163103f099922ab", null ],
    [ "best_trans_per_rot_log_", "classIMP_1_1multifit_1_1FFTFitting.html#a9f8802530728193f986c00ad670138e0", null ],
    [ "cen_trans_", "classIMP_1_1multifit_1_1FFTFitting.html#af7aeda5f915a48828c99a07107d32d90", null ],
    [ "copy_mol_", "classIMP_1_1multifit_1_1FFTFitting.html#a41710d7bc9f67f1980ab7d783f4b175a", null ],
    [ "corr_mode_", "classIMP_1_1multifit_1_1FFTFitting.html#a17b6c9d245a116e858f5904fe9102e00", null ],
    [ "fft_scores_", "classIMP_1_1multifit_1_1FFTFitting.html#a8239ef1504cc0ffac7ec62642b4b451e", null ],
    [ "fft_scores_flipped_", "classIMP_1_1multifit_1_1FFTFitting.html#a6abf892d48116e915c4eb6156a4fa6c2", null ],
    [ "fftw_grid_hi_", "classIMP_1_1multifit_1_1FFTFitting.html#ab9d601a0c3ddb079fe4dcdb00a9c3b59", null ],
    [ "fftw_grid_lo_", "classIMP_1_1multifit_1_1FFTFitting.html#a7ba2bfce2c6f188b253b19ef82f302c3", null ],
    [ "fftw_nvox_c2r_", "classIMP_1_1multifit_1_1FFTFitting.html#a166e229d546006928306bcd2b1ae7a32", null ],
    [ "fftw_nvox_r2c_", "classIMP_1_1multifit_1_1FFTFitting.html#aa6ef2b4b9fe870142e7b73aa5fd1d2b2", null ],
    [ "fftw_pad_factor_", "classIMP_1_1multifit_1_1FFTFitting.html#ab11023944b9dbcb4aee93fff81eb2684", null ],
    [ "fftw_plan_forward_hi_", "classIMP_1_1multifit_1_1FFTFitting.html#a0fa43489d700ec30e1f736088197832a", null ],
    [ "fftw_plan_forward_lo_", "classIMP_1_1multifit_1_1FFTFitting.html#a8922119959c93daf3e06bcd531bd5795", null ],
    [ "fftw_plan_reverse_hi_", "classIMP_1_1multifit_1_1FFTFitting.html#a069871df07929693f93ff68f9731c5a4", null ],
    [ "fftw_r_grid_mol_", "classIMP_1_1multifit_1_1FFTFitting.html#ab339c7ccd74dd6a8f20aa10be474e7b9", null ],
    [ "fftw_scale_", "classIMP_1_1multifit_1_1FFTFitting.html#a22e306c2baad37558f667b7e302676bd", null ],
    [ "fftw_zero_padding_extent_", "classIMP_1_1multifit_1_1FFTFitting.html#ab506f90bac035a98822fc42e4b0ee1a8", null ],
    [ "filtered_kernel_", "classIMP_1_1multifit_1_1FFTFitting.html#af5022d12c2e89b394e40e3a0e2b614eb", null ],
    [ "filtered_kernel_ext_", "classIMP_1_1multifit_1_1FFTFitting.html#a385181ef1002f97535f0fefafc5623b0", null ],
    [ "fits_hash_", "classIMP_1_1multifit_1_1FFTFitting.html#a987dd1b7e0f08867d4faecded65bce03", null ],
    [ "gauss_kernel_", "classIMP_1_1multifit_1_1FFTFitting.html#afba09c0797e2b8bed7c8b3365d13dc3d", null ],
    [ "gauss_kernel_ext_", "classIMP_1_1multifit_1_1FFTFitting.html#aad8ddbcee92364d1663a4229bfdca531", null ],
    [ "gauss_kernel_nvox_", "classIMP_1_1multifit_1_1FFTFitting.html#a00f417d8a257f01addd7cade3c420a19", null ],
    [ "high_mol_", "classIMP_1_1multifit_1_1FFTFitting.html#acee1232b598a0ab5e31cb1c42492363b", null ],
    [ "inside_num_", "classIMP_1_1multifit_1_1FFTFitting.html#a333d9254ef62671be7beebeb070635bb", null ],
    [ "inside_num_flipped_", "classIMP_1_1multifit_1_1FFTFitting.html#a830c0bc1eb478ffe4f68c5deff65f1d8", null ],
    [ "kernel_filter_", "classIMP_1_1multifit_1_1FFTFitting.html#aecde012630cb3fffd29215429fbc1dd4", null ],
    [ "kernel_filter_ext_", "classIMP_1_1multifit_1_1FFTFitting.html#ace7e8b3fcb7151d0a5b6c4e69fbbfffd", null ],
    [ "low_cutoff_", "classIMP_1_1multifit_1_1FFTFitting.html#a19264232c25e84787f21fa006b34cd76", null ],
    [ "low_map_", "classIMP_1_1multifit_1_1FFTFitting.html#a81487e46774c97b75435d104d2d0098e", null ],
    [ "low_map_data_", "classIMP_1_1multifit_1_1FFTFitting.html#a0d437790d7ac0020cb009cc12f5bf2ab", null ],
    [ "map_cen_", "classIMP_1_1multifit_1_1FFTFitting.html#a8cc7ba45852f986b7b98d10922b41e04", null ],
    [ "margin_ignored_in_conv_", "classIMP_1_1multifit_1_1FFTFitting.html#a3718c02ea2ac701a4ed96c04c0958065", null ],
    [ "num_angle_per_voxel_", "classIMP_1_1multifit_1_1FFTFitting.html#a8da106c43c7efe6571fdcc9b73c9af40", null ],
    [ "num_fits_reported_", "classIMP_1_1multifit_1_1FFTFitting.html#aab24cc53fdbaf2b2556f9dcd9fb4bfda", null ],
    [ "nvox_", "classIMP_1_1multifit_1_1FFTFitting.html#a83f8e241de824709768e4ed55a01f6df", null ],
    [ "nx_", "classIMP_1_1multifit_1_1FFTFitting.html#a87be4d8efb2400366138d7e68690009b", null ],
    [ "nx_half_", "classIMP_1_1multifit_1_1FFTFitting.html#ab5728a4a570639534c8606fdca732fed", null ],
    [ "ny_", "classIMP_1_1multifit_1_1FFTFitting.html#aadbb0a1ebc92176e7f8d8ec016d88d36", null ],
    [ "ny_half_", "classIMP_1_1multifit_1_1FFTFitting.html#a9c0722a26008e3979d3c4499ac29ba05", null ],
    [ "nz_", "classIMP_1_1multifit_1_1FFTFitting.html#a33d59dd0e189df1a92a252e85193595d", null ],
    [ "nz_half_", "classIMP_1_1multifit_1_1FFTFitting.html#a05eb0f015d46dae96d68b203ab510eea", null ],
    [ "orig_cen_", "classIMP_1_1multifit_1_1FFTFitting.html#a56f7872c0f48d435a024ca593795dbc2", null ],
    [ "orig_mol_", "classIMP_1_1multifit_1_1FFTFitting.html#adcb52b69e1fdff865dbcdde00128b4f7", null ],
    [ "orig_mol_copy_", "classIMP_1_1multifit_1_1FFTFitting.html#a4774a648899152fb8e4834ea8e5292fc", null ],
    [ "orig_rb_", "classIMP_1_1multifit_1_1FFTFitting.html#ac6bbd98241ca6e137e3df90e73fa58f6", null ],
    [ "origx_", "classIMP_1_1multifit_1_1FFTFitting.html#a36e9db509a0022bb434d20c861884711", null ],
    [ "origy_", "classIMP_1_1multifit_1_1FFTFitting.html#a26cfb88d914fa83d16baf0bda051087e", null ],
    [ "origz_", "classIMP_1_1multifit_1_1FFTFitting.html#aa5f6c9d5ac1e20f652b691a8a12d4e9a", null ],
    [ "resolution_", "classIMP_1_1multifit_1_1FFTFitting.html#a8dbb2dc0cb2469634e0f8c09efff5f8e", null ],
    [ "reversed_fftw_data_", "classIMP_1_1multifit_1_1FFTFitting.html#ab9a8eae5c25d9595b194b2154e76bcdc", null ],
    [ "rots_", "classIMP_1_1multifit_1_1FFTFitting.html#acabd9f85e7e0c6b7e9b972a26f9af43f", null ],
    [ "sampled_map_", "classIMP_1_1multifit_1_1FFTFitting.html#a39ef1528f138f70bb6755c1e30df0680", null ],
    [ "sampled_map_data_", "classIMP_1_1multifit_1_1FFTFitting.html#a744588dbb419eacfca85574e25b413d1", null ],
    [ "sampled_norm_", "classIMP_1_1multifit_1_1FFTFitting.html#a866f7f895d256bec57caa965b7a729a5", null ],
    [ "spacing_", "classIMP_1_1multifit_1_1FFTFitting.html#ad7a14b88ee4f95b8661ecfa7f1198551", null ]
];

==> imp-doc-2.2.1.tar.gz: html/classIMP_1_1multifit_1_1FFTFitting.js <==
var classIMP_1_1multifit_1_1FFTFitting =
[
    [ "~FFTFitting", "classIMP_1_1multifit_1_1FFTFitting.html#a2b09f51e39aa706b36b2337cef4d917d", null ],
    [ "FFTFitting", "classIMP_1_1multifit_1_1FFTFitting.html#a62ebb622f0d78309397c0400981fb658", null ],
    [ "copy_density_data", "classIMP_1_1multifit_1_1FFTFitting.html#aaeb4a52a506bcee42b2cacb393fbaa43", null ],
    [ "crop_margin", "classIMP_1_1multifit_1_1FFTFitting.html#a37d65339d5125709922ec82eba2ce9ed", null ],
    [ "detect_top_fits", "classIMP_1_1multifit_1_1FFTFitting.html#ac4e0b3ee481b867448bdb5e5fed83115", null ],
    [ "do_global_fitting", "classIMP_1_1multifit_1_1FFTFitting.html#a136cac955ee735ec87b1238b82aa67ac", null ],
    [ "do_local_fitting", "classIMP_1_1multifit_1_1FFTFitting.html#ae47864b146f9cf99c92495967e611d01", null ],
    [ "fftw_translational_search", "classIMP_1_1multifit_1_1FFTFitting.html#a74dba3ac8f5c530c2a3dd6bdd1a1cff7", null ],
    [ "get_type_name", "classIMP_1_1multifit_1_1FFTFitting.html#acc987cb7e2795126e5294508dd617280", null ],
    [ "get_unwrapped_index", "classIMP_1_1multifit_1_1FFTFitting.html#acd7df257d05cf51d782a013210e4572d", null ],
    [ "get_version_info", "classIMP_1_1multifit_1_1FFTFitting.html#a35fd010b9b680ba85976e05d5da635dd", null ],
    [ "pad_resolution_map", "classIMP_1_1multifit_1_1FFTFitting.html#accd7f75da3e55504aca2b9abda45ee1e", null ],
    [ "prepare_kernels", "classIMP_1_1multifit_1_1FFTFitting.html#af94977d86c307960a89b1a15d4cbda63", null ],
    [ "prepare_lowres_map", "classIMP_1_1multifit_1_1FFTFitting.html#ab063459cb69df88446f638fded7d95da", null ],
    [ "prepare_poslist", "classIMP_1_1multifit_1_1FFTFitting.html#aced49e5f2dae277cdcc74732c76c4aca", null ],
    [ "prepare_poslist_flipped", "classIMP_1_1multifit_1_1FFTFitting.html#a91969e61ffab79ed9b4f9cd5d222ef37", null ],
    [ "prepare_probe", "classIMP_1_1multifit_1_1FFTFitting.html#ab18f1bb918cf5b1f45d22d800a80fad4", null ],
    [ "asmb_norm_", "classIMP_1_1multifit_1_1FFTFitting.html#a219ce1447901c5e07e307272a5d21345", null ],
    [ "best_fits_", "classIMP_1_1multifit_1_1FFTFitting.html#aabb824cdadbf5fee5163103f099922ab", null ],
    [ "best_trans_per_rot_log_", "classIMP_1_1multifit_1_1FFTFitting.html#a9f8802530728193f986c00ad670138e0", null ],
    [ "cen_trans_", "classIMP_1_1multifit_1_1FFTFitting.html#af7aeda5f915a48828c99a07107d32d90", null ],
    [ "copy_mol_", "classIMP_1_1multifit_1_1FFTFitting.html#a41710d7bc9f67f1980ab7d783f4b175a", null ],
    [ "corr_mode_", "classIMP_1_1multifit_1_1FFTFitting.html#a17b6c9d245a116e858f5904fe9102e00", null ],
    [ "fft_scores_", "classIMP_1_1multifit_1_1FFTFitting.html#a8239ef1504cc0ffac7ec62642b4b451e", null ],
    [ "fft_scores_flipped_", "classIMP_1_1multifit_1_1FFTFitting.html#a6abf892d48116e915c4eb6156a4fa6c2", null ],
    [ "fftw_grid_hi_", "classIMP_1_1multifit_1_1FFTFitting.html#ab9d601a0c3ddb079fe4dcdb00a9c3b59", null ],
    [ "fftw_grid_lo_", "classIMP_1_1multifit_1_1FFTFitting.html#a7ba2bfce2c6f188b253b19ef82f302c3", null ],
    [ "fftw_nvox_c2r_", "classIMP_1_1multifit_1_1FFTFitting.html#a166e229d546006928306bcd2b1ae7a32", null ],
    [ "fftw_nvox_r2c_", "classIMP_1_1multifit_1_1FFTFitting.html#aa6ef2b4b9fe870142e7b73aa5fd1d2b2", null ],
    [ "fftw_pad_factor_", "classIMP_1_1multifit_1_1FFTFitting.html#ab11023944b9dbcb4aee93fff81eb2684", null ],
    [ "fftw_plan_forward_hi_", "classIMP_1_1multifit_1_1FFTFitting.html#a0fa43489d700ec30e1f736088197832a", null ],
    [ "fftw_plan_forward_lo_", "classIMP_1_1multifit_1_1FFTFitting.html#a8922119959c93daf3e06bcd531bd5795", null ],
    [ "fftw_plan_reverse_hi_", "classIMP_1_1multifit_1_1FFTFitting.html#a069871df07929693f93ff68f9731c5a4", null ],
    [ "fftw_r_grid_mol_", "classIMP_1_1multifit_1_1FFTFitting.html#ab339c7ccd74dd6a8f20aa10be474e7b9", null ],
    [ "fftw_scale_", "classIMP_1_1multifit_1_1FFTFitting.html#a22e306c2baad37558f667b7e302676bd", null ],
    [ "fftw_zero_padding_extent_", "classIMP_1_1multifit_1_1FFTFitting.html#ab506f90bac035a98822fc42e4b0ee1a8", null ],
    [ "filtered_kernel_", "classIMP_1_1multifit_1_1FFTFitting.html#af5022d12c2e89b394e40e3a0e2b614eb", null ],
    [ "filtered_kernel_ext_", "classIMP_1_1multifit_1_1FFTFitting.html#a385181ef1002f97535f0fefafc5623b0", null ],
    [ "fits_hash_", "classIMP_1_1multifit_1_1FFTFitting.html#a987dd1b7e0f08867d4faecded65bce03", null ],
    [ "gauss_kernel_", "classIMP_1_1multifit_1_1FFTFitting.html#afba09c0797e2b8bed7c8b3365d13dc3d", null ],
    [ "gauss_kernel_ext_", "classIMP_1_1multifit_1_1FFTFitting.html#aad8ddbcee92364d1663a4229bfdca531", null ],
    [ "gauss_kernel_nvox_", "classIMP_1_1multifit_1_1FFTFitting.html#a00f417d8a257f01addd7cade3c420a19", null ],
    [ "high_mol_", "classIMP_1_1multifit_1_1FFTFitting.html#acee1232b598a0ab5e31cb1c42492363b", null ],
    [ "inside_num_", "classIMP_1_1multifit_1_1FFTFitting.html#a333d9254ef62671be7beebeb070635bb", null ],
    [ "inside_num_flipped_", "classIMP_1_1multifit_1_1FFTFitting.html#a830c0bc1eb478ffe4f68c5deff65f1d8", null ],
    [ "kernel_filter_", "classIMP_1_1multifit_1_1FFTFitting.html#aecde012630cb3fffd29215429fbc1dd4", null ],
    [ "kernel_filter_ext_", "classIMP_1_1multifit_1_1FFTFitting.html#ace7e8b3fcb7151d0a5b6c4e69fbbfffd", null ],
    [ "low_cutoff_", "classIMP_1_1multifit_1_1FFTFitting.html#a19264232c25e84787f21fa006b34cd76", null ],
    [ "low_map_", "classIMP_1_1multifit_1_1FFTFitting.html#a81487e46774c97b75435d104d2d0098e", null ],
    [ "low_map_data_", "classIMP_1_1multifit_1_1FFTFitting.html#a0d437790d7ac0020cb009cc12f5bf2ab", null ],
    [ "map_cen_", "classIMP_1_1multifit_1_1FFTFitting.html#a8cc7ba45852f986b7b98d10922b41e04", null ],
    [ "margin_ignored_in_conv_", "classIMP_1_1multifit_1_1FFTFitting.html#a3718c02ea2ac701a4ed96c04c0958065", null ],
    [ "num_angle_per_voxel_", "classIMP_1_1multifit_1_1FFTFitting.html#a8da106c43c7efe6571fdcc9b73c9af40", null ],
    [ "num_fits_reported_", "classIMP_1_1multifit_1_1FFTFitting.html#aab24cc53fdbaf2b2556f9dcd9fb4bfda", null ],
    [ "nvox_", "classIMP_1_1multifit_1_1FFTFitting.html#a83f8e241de824709768e4ed55a01f6df", null ],
    [ "nx_", "classIMP_1_1multifit_1_1FFTFitting.html#a87be4d8efb2400366138d7e68690009b", null ],
    [ "nx_half_", "classIMP_1_1multifit_1_1FFTFitting.html#ab5728a4a570639534c8606fdca732fed", null ],
    [ "ny_", "classIMP_1_1multifit_1_1FFTFitting.html#aadbb0a1ebc92176e7f8d8ec016d88d36", null ],
    [ "ny_half_", "classIMP_1_1multifit_1_1FFTFitting.html#a9c0722a26008e3979d3c4499ac29ba05", null ],
    [ "nz_", "classIMP_1_1multifit_1_1FFTFitting.html#a33d59dd0e189df1a92a252e85193595d", null ],
    [ "nz_half_", "classIMP_1_1multifit_1_1FFTFitting.html#a05eb0f015d46dae96d68b203ab510eea", null ],
    [ "orig_cen_", "classIMP_1_1multifit_1_1FFTFitting.html#a56f7872c0f48d435a024ca593795dbc2", null ],
    [ "orig_mol_", "classIMP_1_1multifit_1_1FFTFitting.html#adcb52b69e1fdff865dbcdde00128b4f7", null ],
    [ "orig_mol_copy_", "classIMP_1_1multifit_1_1FFTFitting.html#a4774a648899152fb8e4834ea8e5292fc", null ],
    [ "orig_rb_", "classIMP_1_1multifit_1_1FFTFitting.html#ac6bbd98241ca6e137e3df90e73fa58f6", null ],
    [ "origx_", "classIMP_1_1multifit_1_1FFTFitting.html#a36e9db509a0022bb434d20c861884711", null ],
    [ "origy_", "classIMP_1_1multifit_1_1FFTFitting.html#a26cfb88d914fa83d16baf0bda051087e", null ],
    [ "origz_", "classIMP_1_1multifit_1_1FFTFitting.html#aa5f6c9d5ac1e20f652b691a8a12d4e9a", null ],
    [ "resolution_", "classIMP_1_1multifit_1_1FFTFitting.html#a8dbb2dc0cb2469634e0f8c09efff5f8e", null ],
    [ "reversed_fftw_data_", "classIMP_1_1multifit_1_1FFTFitting.html#ab9a8eae5c25d9595b194b2154e76bcdc", null ],
    [ "rots_", "classIMP_1_1multifit_1_1FFTFitting.html#acabd9f85e7e0c6b7e9b972a26f9af43f", null ],
    [ "sampled_map_", "classIMP_1_1multifit_1_1FFTFitting.html#a39ef1528f138f70bb6755c1e30df0680", null ],
    [ "sampled_map_data_", "classIMP_1_1multifit_1_1FFTFitting.html#a744588dbb419eacfca85574e25b413d1", null ],
    [ "sampled_norm_", "classIMP_1_1multifit_1_1FFTFitting.html#a866f7f895d256bec57caa965b7a729a5", null ],
    [ "spacing_", "classIMP_1_1multifit_1_1FFTFitting.html#ad7a14b88ee4f95b8661ecfa7f1198551", null ]
];
